[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-109-gd6e99fa

2016-06-10 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  d6e99fa8345f07a72308b8b33f4a31aa7fe9a0fd (commit)
  from  c5d71b28ec2682ec160dd35015e90dd5b81a5605 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d6e99fa8345f07a72308b8b33f4a31aa7fe9a0fd
commit d6e99fa8345f07a72308b8b33f4a31aa7fe9a0fd
Author: Kitware Robot 
AuthorDate: Sat Jun 11 00:01:07 2016 -0400
Commit: Kitware Robot 
CommitDate: Sat Jun 11 00:01:07 2016 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 254d9de..a27d5e1 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 6)
-set(CMake_VERSION_PATCH 20160610)
+set(CMake_VERSION_PATCH 20160611)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-233-gd6df33e

2016-06-10 Thread Daniel Pfeifer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  d6df33e4f52f1cc2302df0a6ebdfdfb45cea3d9a (commit)
   via  a16bf141bc5d393b27d13d8235d95a1b034052c2 (commit)
   via  bd9e551c1a13f566e6ffe8cdd1262b7628ed5330 (commit)
  from  6d1e598aa41352087b2e113e05897820f566b881 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d6df33e4f52f1cc2302df0a6ebdfdfb45cea3d9a
commit d6df33e4f52f1cc2302df0a6ebdfdfb45cea3d9a
Merge: 6d1e598 a16bf14
Author: Daniel Pfeifer 
AuthorDate: Fri Jun 10 12:41:33 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 12:41:33 2016 -0400

Merge topic 'add-braces' into next

a16bf141 Add missing braces around statements.
bd9e551c PseudoMemcheck: revise style with clang-format.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a16bf141bc5d393b27d13d8235d95a1b034052c2
commit a16bf141bc5d393b27d13d8235d95a1b034052c2
Author: Daniel Pfeifer 
AuthorDate: Fri Jun 10 18:36:24 2016 +0200
Commit: Daniel Pfeifer 
CommitDate: Fri Jun 10 18:36:24 2016 +0200

Add missing braces around statements.

Apply fixits of clang-tidy's readability-braces-around-statements
checker.

diff --git a/Source/CPack/IFW/cmCPackIFWGenerator.cxx 
b/Source/CPack/IFW/cmCPackIFWGenerator.cxx
index c1ff526..b47d46e 100644
--- a/Source/CPack/IFW/cmCPackIFWGenerator.cxx
+++ b/Source/CPack/IFW/cmCPackIFWGenerator.cxx
@@ -345,18 +345,21 @@ cmCPackComponent* cmCPackIFWGenerator::GetComponent(
   const std::string& projectName, const std::string& componentName)
 {
   ComponentsMap::iterator cit = Components.find(componentName);
-  if (cit != Components.end())
+  if (cit != Components.end()) {
 return &(cit->second);
+  }
 
   cmCPackComponent* component =
 cmCPackGenerator::GetComponent(projectName, componentName);
-  if (!component)
+  if (!component) {
 return component;
+  }
 
   std::string name = GetComponentPackageName(component);
   PackagesMap::iterator pit = Packages.find(name);
-  if (pit != Packages.end())
+  if (pit != Packages.end()) {
 return component;
+  }
 
   cmCPackIFWPackage* package = &Packages[name];
   package->Name = name;
@@ -387,13 +390,15 @@ cmCPackComponentGroup* 
cmCPackIFWGenerator::GetComponentGroup(
 {
   cmCPackComponentGroup* group =
 cmCPackGenerator::GetComponentGroup(projectName, groupName);
-  if (!group)
+  if (!group) {
 return group;
+  }
 
   std::string name = GetGroupPackageName(group);
   PackagesMap::iterator pit = Packages.find(name);
-  if (pit != Packages.end())
+  if (pit != Packages.end()) {
 return group;
+  }
 
   cmCPackIFWPackage* package = &Packages[name];
   package->Name = name;
@@ -462,8 +467,9 @@ std::string cmCPackIFWGenerator::GetGroupPackageName(
   cmCPackComponentGroup* group) const
 {
   std::string name;
-  if (!group)
+  if (!group) {
 return name;
+  }
   if (cmCPackIFWPackage* package = GetGroupPackage(group)) {
 return package->Name;
   }
@@ -488,8 +494,9 @@ std::string cmCPackIFWGenerator::GetComponentPackageName(
   cmCPackComponent* component) const
 {
   std::string name;
-  if (!component)
+  if (!component) {
 return name;
+  }
   if (cmCPackIFWPackage* package = GetComponentPackage(component)) {
 return package->Name;
   }
@@ -534,8 +541,9 @@ cmCPackIFWRepository* cmCPackIFWGenerator::GetRepository(
   const std::string& repositoryName)
 {
   RepositoriesMap::iterator rit = Repositories.find(repositoryName);
-  if (rit != Repositories.end())
+  if (rit != Repositories.end()) {
 return &(rit->second);
+  }
 
   cmCPackIFWRepository* repository = &Repositories[repositoryName];
   repository->Name = repositoryName;
diff --git a/Source/CPack/IFW/cmCPackIFWInstaller.cxx 
b/Source/CPack/IFW/cmCPackIFWInstaller.cxx
index dfc509b..74f6da6 100644
--- a/Source/CPack/IFW/cmCPackIFWInstaller.cxx
+++ b/Source/CPack/IFW/cmCPackIFWInstaller.cxx
@@ -343,6 +343,7 @@ void cmCPackIFWInstaller::GeneratePackageFiles()
 
 void cmCPackIFWInstaller::WriteGeneratedByToStrim(cmXMLWriter& xout)
 {
-  if (Generator)
+  if (Generator) {
 Generator->WriteGeneratedByToStrim(xout);
+  }
 }
diff --git a/Source/CPack/IFW/cmCPackIFWPackage.cxx 
b/Source/CPack/IFW/cmCPackIFWPackage.cxx
index ad153d1..c44e389 100644
--- a/Source/CPack/IFW/cmCPackIFWPackage.cxx
+++ b/Source/CPack/IFW/cmCPackIFWPackage.cxx
@@ -71,8 +71,9 @@ cmCPackIFWPackage::DependenceStruct::DependenceStruct(
 
 std::string cmCPackIFWPackage::DependenceStruct::NameWithCompare() const
 {
-  if (Compare.Type == CompareNone)
+  if (Compare.Type == CompareNone) {
 return Name;
+  }
 
   std::string result = Name;
 

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-230-g6d1e598

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  6d1e598aa41352087b2e113e05897820f566b881 (commit)
   via  896ad251de49f167f4ce3cbbcf9a6cce85a16681 (commit)
  from  6fc549fd0f5c1ad49aab7beb0c9a8ea90d7f1aed (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6d1e598aa41352087b2e113e05897820f566b881
commit 6d1e598aa41352087b2e113e05897820f566b881
Merge: 6fc549f 896ad25
Author: Brad King 
AuthorDate: Fri Jun 10 11:10:19 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 11:10:19 2016 -0400

Merge topic 'find-lib32' into next

896ad251 Teach find_library and find_package to search lib32 paths (#11260)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=896ad251de49f167f4ce3cbbcf9a6cce85a16681
commit 896ad251de49f167f4ce3cbbcf9a6cce85a16681
Author: Daniel Scharrer 
AuthorDate: Fri Jun 10 16:11:18 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 11:09:16 2016 -0400

Teach find_library and find_package to search lib32 paths (#11260)

Add a ``FIND_LIBRARY_USE_LIB32_PATHS`` global property analogous to the
``FIND_LIBRARY_USE_LIB64_PATHS`` property.  This helps find commands on
multilib systems that use ``lib32`` directories and either do not have
``lib`` symlinks or point ``lib`` to ``lib64``.

diff --git a/Help/command/find_library.rst b/Help/command/find_library.rst
index 31e6ec0..1eb50f7 100644
--- a/Help/command/find_library.rst
+++ b/Help/command/find_library.rst
@@ -49,6 +49,13 @@ path to the framework ``/A.framework``.  When a 
full path to a
 framework is used as a library, CMake will use a ``-framework A``, and a
 ``-F`` to link the framework to the target.
 
+If the :prop_gbl:`FIND_LIBRARY_USE_LIB32_PATHS` global property is set
+all search paths will be tested as normal, with ``32/`` appended, and
+with all matches of ``lib/`` replaced with ``lib32/``.  This property is
+automatically set for the platforms that are known to need it if at
+least one of the languages supported by the :command:`project` command
+is enabled.
+
 If the :prop_gbl:`FIND_LIBRARY_USE_LIB64_PATHS` global property is set
 all search paths will be tested as normal, with ``64/`` appended, and
 with all matches of ``lib/`` replaced with ``lib64/``.  This property is
diff --git a/Help/manual/cmake-properties.7.rst 
b/Help/manual/cmake-properties.7.rst
index 3403dcd..3574b7f 100644
--- a/Help/manual/cmake-properties.7.rst
+++ b/Help/manual/cmake-properties.7.rst
@@ -24,6 +24,7 @@ Properties of Global Scope
/prop_gbl/DISABLED_FEATURES
/prop_gbl/ENABLED_FEATURES
/prop_gbl/ENABLED_LANGUAGES
+   /prop_gbl/FIND_LIBRARY_USE_LIB32_PATHS
/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS
/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING
/prop_gbl/GLOBAL_DEPENDS_DEBUG_MODE
diff --git a/Help/prop_gbl/FIND_LIBRARY_USE_LIB32_PATHS.rst 
b/Help/prop_gbl/FIND_LIBRARY_USE_LIB32_PATHS.rst
new file mode 100644
index 000..ce18b65
--- /dev/null
+++ b/Help/prop_gbl/FIND_LIBRARY_USE_LIB32_PATHS.rst
@@ -0,0 +1,10 @@
+FIND_LIBRARY_USE_LIB32_PATHS
+
+
+Whether the :command:`find_library` command should automatically search
+``lib32`` directories.
+
+``FIND_LIBRARY_USE_LIB32_PATHS`` is a boolean specifying whether the
+:command:`find_library` command should automatically search the ``lib32``
+variant of directories called ``lib`` in the search path when building 32-bit
+binaries.
diff --git a/Help/release/dev/find-lib32.rst b/Help/release/dev/find-lib32.rst
new file mode 100644
index 000..00818dc
--- /dev/null
+++ b/Help/release/dev/find-lib32.rst
@@ -0,0 +1,7 @@
+find-lib32
+--
+
+* The :command:`find_library` and :command:`find_package` commands learned
+  to search in ``lib32/`` directories when the build targets a 32-bit
+  architecture.  See the :prop_gbl:`FIND_LIBRARY_USE_LIB32_PATHS` global
+  property.
diff --git a/Auxiliary/bash-completion/cpack b/Auxiliary/bash-completion/cpack
index 05e0e93..cf5751f 100644
--- a/Auxiliary/bash-completion/cpack
+++ b/Auxiliary/bash-completion/cpack
@@ -48,6 +48,26 @@ _cpack()
 grep -v "^cpack version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( cpack --help-manual-list 2>/dev/null|
+grep -v "^cpack version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( cpack --help-module-list 2>/dev/null|
+grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( cpack --help-policy-list 2>/dev/null 
|
+grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( cpack --help-property-list \
+2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
 --help-variable)
 COMPREPLY=( $( compgen -W '$( cpack --help-variable-list \
 2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b08cae9b0e9bad96e4615c1bbf9bbd00802e6985
commit b08cae9b0e9bad96e4615c1bbf9bbd00802e6985
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 10:46:19 2016 -0400

bash-completion: Add ctest --help-{manual,module,policy,property,variable}

diff --git a/Auxiliary/bash-completion/ctest b/Auxiliary/bash-completion/ctest
index 387672a..49343bb 100644
--- a/Auxiliary/bash-completion/ctest
+++ b/Auxiliary/bash-completion/ctest
@@ -72,11 +72,37 @@ _ctest()
 COMPREPLY=( $( compgen -W '0 1' -- "$cur" ) )
 return
 ;;
+
 --help-command)
 COMPREPLY=( $( compgen -W '$( ctest --help-command-list 
2>/dev/null|
 grep -v "^ctest version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( ctest --help-manual-list 2>/dev/null|
+grep -v "^ctest version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( ctest --help-module-list 2>/dev/null|
+grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( ctest --help-policy-list 2>/dev/null 
|
+grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( ctest --help-property-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-variable)
+COMPREPLY=( $( compgen -W '$( ctest --help-variable-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
 esac
 
 if [[ "$cur" == -* ]]; then

https://cmake.org/gitweb?p=cmake.git;a=com

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-224-g78dddca

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  78dddcaf7e33e7d70516901699c7315ed53e7eca (commit)
   via  ecc7973fdaa488110cc96cd8377b9fd33ba35185 (commit)
  from  74ee264c0bcd5f5a003cc8e3ebf8f1b38e2ac3e5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=78dddcaf7e33e7d70516901699c7315ed53e7eca
commit 78dddcaf7e33e7d70516901699c7315ed53e7eca
Merge: 74ee264 ecc7973
Author: Brad King 
AuthorDate: Fri Jun 10 10:47:17 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 10:47:17 2016 -0400

Merge topic 'bash-completion' into next

ecc7973f Update --help-policy completion with comtemporary cmake tools.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ecc7973fdaa488110cc96cd8377b9fd33ba35185
commit ecc7973fdaa488110cc96cd8377b9fd33ba35185
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 16:07:06 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 10:44:24 2016 -0400

Update --help-policy completion with comtemporary cmake tools.

This was a leftover from previous patch.

diff --git a/Auxiliary/bash-completion/cmake b/Auxiliary/bash-completion/cmake
index 6997d47..6061129 100644
--- a/Auxiliary/bash-completion/cmake
+++ b/Auxiliary/bash-completion/cmake
@@ -132,8 +132,8 @@ _cmake()
 return
 ;;
  --help-policy)
-COMPREPLY=( $( compgen -W '$( cmake --help-policies 2>/dev/null |
-grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+COMPREPLY=( $( compgen -W '$( cmake --help-policy-list 2>/dev/null 
|
+grep -v "^cmake version " )' -- "$cur" ) )
 return
 ;;
  --help-property)
diff --git a/Auxiliary/bash-completion/cpack b/Auxiliary/bash-completion/cpack
index b30df8a..cf5751f 100644
--- a/Auxiliary/bash-completion/cpack
+++ b/Auxiliary/bash-completion/cpack
@@ -59,8 +59,8 @@ _cpack()
 return
 ;;
 --help-policy)
-COMPREPLY=( $( compgen -W '$( cpack --help-policies 2>/dev/null |
-grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+COMPREPLY=( $( compgen -W '$( cpack --help-policy-list 2>/dev/null 
|
+grep -v "^cpack version " )' -- "$cur" ) )
 return
 ;;
 --help-property)
diff --git a/Auxiliary/bash-completion/ctest b/Auxiliary/bash-completion/ctest
index d15cc98..49343bb 100644
--- a/Auxiliary/bash-completion/ctest
+++ b/Auxiliary/bash-completion/ctest
@@ -89,8 +89,8 @@ _ctest()
 return
 ;;
 --help-policy)
-COMPREPLY=( $( compgen -W '$( ctest --help-policies 2>/dev/null |
-grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+COMPREPLY=( $( compgen -W '$( ctest --help-policy-list 2>/dev/null 
|
+grep -v "^ctest version " )' -- "$cur" ) )
 return
 ;;
 --help-property)

---

Summary of changes:
 Auxiliary/bash-completion/cmake |4 ++--
 Auxiliary/bash-completion/cpack |4 ++--
 Auxiliary/bash-completion/ctest |4 ++--
 3 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-222-g74ee264

2016-06-10 Thread Bill Hoffman
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  74ee264c0bcd5f5a003cc8e3ebf8f1b38e2ac3e5 (commit)
   via  89ae032fb010197715d8308697987421083d604a (commit)
   via  a8942cd2b555f72c39fdac6df54ecff52d58e975 (commit)
   via  24d7e3ea16e7cb687010c03a35621053f8ed74fb (commit)
  from  c0253804aed4f21ba5b9dede973a59bc65f65e47 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=74ee264c0bcd5f5a003cc8e3ebf8f1b38e2ac3e5
commit 74ee264c0bcd5f5a003cc8e3ebf8f1b38e2ac3e5
Merge: c025380 89ae032
Author: Bill Hoffman 
AuthorDate: Fri Jun 10 10:31:43 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 10:31:43 2016 -0400

Merge topic 'link_what_you_use' into next

89ae032f use inline markup for rst files and call ldd directly
a8942cd2 add documentation for LINK_WHAT_YOU_USE
24d7e3ea Add support for ldd -u -r as link what you use


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=89ae032fb010197715d8308697987421083d604a
commit 89ae032fb010197715d8308697987421083d604a
Author: Bill Hoffman 
AuthorDate: Thu Jun 9 17:12:13 2016 -0400
Commit: Bill Hoffman 
CommitDate: Thu Jun 9 17:12:13 2016 -0400

use inline markup for rst files and call ldd directly

diff --git a/Help/prop_tgt/LINK_WHAT_YOU_USE.rst 
b/Help/prop_tgt/LINK_WHAT_YOU_USE.rst
index 76bfafa..32d6edb 100644
--- a/Help/prop_tgt/LINK_WHAT_YOU_USE.rst
+++ b/Help/prop_tgt/LINK_WHAT_YOU_USE.rst
@@ -1,10 +1,10 @@
 LINK_WHAT_YOU_USE
 ---
 
-This is a boolean option that when set to TRUE will automatically run
-ldd -r -u on the target after it is linked. In addition, the linker flag
--Wl,--no-as-needed will be passed to the target with the link command so that
-all libraries specified on the command line will be linked into the
+This is a boolean option that when set to ``TRUE`` will automatically run
+``ldd -r -u`` on the target after it is linked. In addition, the linker flag
+``-Wl,--no-as-needed`` will be passed to the target with the link command so
+that all libraries specified on the command line will be linked into the
 target. This will result in the link producing a list of libraries that
 provide no symbols used by this target but are being linked to it.
 This is only applicable to executable and shared library targets and
diff --git a/Tests/RunCMake/CMakeLists.txt b/Tests/RunCMake/CMakeLists.txt
index 4be81e9..8fb91a9 100644
--- a/Tests/RunCMake/CMakeLists.txt
+++ b/Tests/RunCMake/CMakeLists.txt
@@ -307,9 +307,8 @@ if(CMAKE_OSX_ARCHITECTURES AND XCODE AND NOT 
"${XCODE_VERSION}" MATCHES "^[^12]"
 endif()
 
 if("${CMAKE_GENERATOR}" MATCHES "Make|Ninja")
-  find_program(LDD_PATH ldd)
-  if(UNIX AND LDD_PATH)
-execute_process(COMMAND ${LDD_PATH} --help
+  if(UNIX)
+execute_process(COMMAND ldd --help
   OUTPUT_VARIABLE LDD_HELP)
 if("${LDD_HELP}" MATCHES
 "(-r, --function-relocs.*process data and function relocations|-u, 
--unused.*print unused direct dependencies)")

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a8942cd2b555f72c39fdac6df54ecff52d58e975
commit a8942cd2b555f72c39fdac6df54ecff52d58e975
Author: Bill Hoffman 
AuthorDate: Thu Jun 9 16:32:24 2016 -0400
Commit: Bill Hoffman 
CommitDate: Thu Jun 9 16:32:24 2016 -0400

add documentation for LINK_WHAT_YOU_USE

diff --git a/Help/manual/cmake-properties.7.rst 
b/Help/manual/cmake-properties.7.rst
index 3403dcd..6a7560a 100644
--- a/Help/manual/cmake-properties.7.rst
+++ b/Help/manual/cmake-properties.7.rst
@@ -217,6 +217,7 @@ Properties on Targets
/prop_tgt/LINK_LIBRARIES
/prop_tgt/LINK_SEARCH_END_STATIC
/prop_tgt/LINK_SEARCH_START_STATIC
+   /prop_tgt/LINK_WHAT_YOU_USE
/prop_tgt/LOCATION_CONFIG
/prop_tgt/LOCATION
/prop_tgt/MACOSX_BUNDLE_INFO_PLIST
diff --git a/Help/manual/cmake-variables.7.rst 
b/Help/manual/cmake-variables.7.rst
index 85b8eae..36d00dc 100644
--- a/Help/manual/cmake-variables.7.rst
+++ b/Help/manual/cmake-variables.7.rst
@@ -275,6 +275,7 @@ Variables that Control the Build
/variable/CMAKE_LINK_INTERFACE_LIBRARIES
/variable/CMAKE_LINK_LIBRARY_FILE_FLAG
/variable/CMAKE_LINK_LIBRARY_FLAG
+   /variable/CMAKE_LINK_WHAT_YOU_USE
/variable/CMAKE_MACOSX_BUNDLE
/variable/CMAKE_MACOSX_RPATH
/variable/CMAKE_MAP_IMPORTED_CONFIG_CONFIG
diff --git a/Help/prop_tgt/LINK_WHAT_YOU_USE.rst 
b/Help/prop_tgt/LINK_WHAT_YOU_USE.rst
new file mode 100644
index 000..76bfafa
--- /dev/null
+++ b/Help/prop_tgt/LINK_WHAT_YOU_USE.rst
@@ -0,0 +1,15 @@
+LINK_WHAT_YOU_USE
+---
+
+This is a boolean option that when set to TRUE wil

[Cmake-commits] CMake branch, release, updated. v3.6.0-rc1-14-gcc7e9d1

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, release has been updated
   via  cc7e9d1d90b7e0906149613bddd94895160c8629 (commit)
   via  f28401554af8fe48994b0c08668f0c1408708fe1 (commit)
   via  b55039ce5baeb76f0ad9599ceb85ae65bc20b2d7 (commit)
   via  1b18180ed4a808f706c4df2f03826e7e9804487b (commit)
   via  558e4d1ed64a02f53592403158e0549bbcee98f1 (commit)
   via  fb30b1a2822a43a26368da8245d107c347526b04 (commit)
   via  dbc9f73d0e9ed5fd8a2a0e64e17d81f860643efd (commit)
  from  cd1f0a824e84f4d7f37fb526528e1cfb04d5c250 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 Help/command/ctest_update.rst |4 
 Help/manual/ctest.1.rst   |5 +
 Source/QtDialog/CMakeSetup.cxx|   34 +
 Utilities/cmlibarchive/CMakeLists.txt |1 +
 4 files changed, 44 insertions(+)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-108-gc5d71b2

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  c5d71b28ec2682ec160dd35015e90dd5b81a5605 (commit)
   via  cc7e9d1d90b7e0906149613bddd94895160c8629 (commit)
   via  b55039ce5baeb76f0ad9599ceb85ae65bc20b2d7 (commit)
   via  fb30b1a2822a43a26368da8245d107c347526b04 (commit)
  from  98aafb2ad64daa0617b3a71ec61f692d5aa205ce (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-218-gc025380

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c0253804aed4f21ba5b9dede973a59bc65f65e47 (commit)
   via  c5d71b28ec2682ec160dd35015e90dd5b81a5605 (commit)
   via  cc7e9d1d90b7e0906149613bddd94895160c8629 (commit)
   via  b55039ce5baeb76f0ad9599ceb85ae65bc20b2d7 (commit)
   via  fb30b1a2822a43a26368da8245d107c347526b04 (commit)
  from  a7791154ed2f30a0bf12eff52617a95c54e9b0e0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c0253804aed4f21ba5b9dede973a59bc65f65e47
commit c0253804aed4f21ba5b9dede973a59bc65f65e47
Merge: a779115 c5d71b2
Author: Brad King 
AuthorDate: Fri Jun 10 09:57:37 2016 -0400
Commit: Brad King 
CommitDate: Fri Jun 10 09:57:37 2016 -0400

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-213-ga779115

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  a7791154ed2f30a0bf12eff52617a95c54e9b0e0 (commit)
   via  eacb75de484b3a8cc3be37d99f2489502270206e (commit)
   via  c8178a7772e103df57aea944d01d77b08c13bbb4 (commit)
   via  f67afbdc4a97c0b0305763e714d22dd04ead16f3 (commit)
  from  8c63b7000d98ed82f83706253a0c73d19b9c354b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a7791154ed2f30a0bf12eff52617a95c54e9b0e0
commit a7791154ed2f30a0bf12eff52617a95c54e9b0e0
Merge: 8c63b70 eacb75d
Author: Brad King 
AuthorDate: Fri Jun 10 09:54:39 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:54:39 2016 -0400

Merge topic 'bash-completion' into next

eacb75de bash-completion: Add cpack --help-{manual,module,policy,property}
c8178a77 bash-completion: Add ctest 
--help-{manual,module,policy,property,variable}
f67afbdc bash-completion: Add cmake --help-manual


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=eacb75de484b3a8cc3be37d99f2489502270206e
commit eacb75de484b3a8cc3be37d99f2489502270206e
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:54:29 2016 -0400

bash-completion: Add cpack --help-{manual,module,policy,property}

diff --git a/Auxiliary/bash-completion/cpack b/Auxiliary/bash-completion/cpack
index 05e0e93..b30df8a 100644
--- a/Auxiliary/bash-completion/cpack
+++ b/Auxiliary/bash-completion/cpack
@@ -48,6 +48,26 @@ _cpack()
 grep -v "^cpack version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( cpack --help-manual-list 2>/dev/null|
+grep -v "^cpack version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( cpack --help-module-list 2>/dev/null|
+grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( cpack --help-policies 2>/dev/null |
+grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( cpack --help-property-list \
+2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
 --help-variable)
 COMPREPLY=( $( compgen -W '$( cpack --help-variable-list \
 2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c8178a7772e103df57aea944d01d77b08c13bbb4
commit c8178a7772e103df57aea944d01d77b08c13bbb4
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:54:29 2016 -0400

bash-completion: Add ctest --help-{manual,module,policy,property,variable}

diff --git a/Auxiliary/bash-completion/ctest b/Auxiliary/bash-completion/ctest
index 387672a..d15cc98 100644
--- a/Auxiliary/bash-completion/ctest
+++ b/Auxiliary/bash-completion/ctest
@@ -72,11 +72,37 @@ _ctest()
 COMPREPLY=( $( compgen -W '0 1' -- "$cur" ) )
 return
 ;;
+
 --help-command)
 COMPREPLY=( $( compgen -W '$( ctest --help-command-list 
2>/dev/null|
 grep -v "^ctest version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( ctest --help-manual-list 2>/dev/null|
+grep -v "^ctest version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( ctest --help-module-list 2>/dev/null|
+grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( ctest --help-policies 2>/dev/null |
+grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( ctest --help-property-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-variable)
+COMPREPLY=( $( compgen -W '$( ctest --help-variable-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
 esac
 
 if [[ "$cur" == -* ]]; then

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f67af

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-209-g8c63b70

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  8c63b7000d98ed82f83706253a0c73d19b9c354b (commit)
   via  dc7d397fe23dcf3dc6195af25da3bdb5f03dffa8 (commit)
   via  abdb88e7f742246be27bd4c13dbe72eef983d986 (commit)
   via  846d2876bb6ad0345f77660ea6154e2af8efbdde (commit)
  from  ceb8b8371ad2426dec35210e0de96fda69bc6c9a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8c63b7000d98ed82f83706253a0c73d19b9c354b
commit 8c63b7000d98ed82f83706253a0c73d19b9c354b
Merge: ceb8b83 dc7d397
Author: Brad King 
AuthorDate: Fri Jun 10 09:53:34 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:53:34 2016 -0400

Merge topic 'bash-completion' into next

dc7d397f bash-completion: Add cpack --help-{manual,module,policy,property}
abdb88e7 bash-completion: Add ctest 
--help-{manual,module,policy,property,variable}
846d2876 bash-completion: Add cmake --help-manual


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dc7d397fe23dcf3dc6195af25da3bdb5f03dffa8
commit dc7d397fe23dcf3dc6195af25da3bdb5f03dffa8
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:50:21 2016 -0400

bash-completion: Add cpack --help-{manual,module,policy,property}

diff --git a/Auxiliary/bash-completion/cpack b/Auxiliary/bash-completion/cpack
index 05e0e93..b30df8a 100644
--- a/Auxiliary/bash-completion/cpack
+++ b/Auxiliary/bash-completion/cpack
@@ -48,6 +48,26 @@ _cpack()
 grep -v "^cpack version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( cpack --help-manual-list 2>/dev/null|
+grep -v "^cpack version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( cpack --help-module-list 2>/dev/null|
+grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( cpack --help-policies 2>/dev/null |
+grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( cpack --help-property-list \
+2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )
+return
+;;
 --help-variable)
 COMPREPLY=( $( compgen -W '$( cpack --help-variable-list \
 2>/dev/null | grep -v "^cpack version " )' -- "$cur" ) )

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=abdb88e7f742246be27bd4c13dbe72eef983d986
commit abdb88e7f742246be27bd4c13dbe72eef983d986
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:50:01 2016 -0400

bash-completion: Add ctest --help-{manual,module,policy,property,variable}

diff --git a/Auxiliary/bash-completion/ctest b/Auxiliary/bash-completion/ctest
index 387672a..d15cc98 100644
--- a/Auxiliary/bash-completion/ctest
+++ b/Auxiliary/bash-completion/ctest
@@ -72,11 +72,37 @@ _ctest()
 COMPREPLY=( $( compgen -W '0 1' -- "$cur" ) )
 return
 ;;
+
 --help-command)
 COMPREPLY=( $( compgen -W '$( ctest --help-command-list 
2>/dev/null|
 grep -v "^ctest version " )' -- "$cur" ) )
 return
 ;;
+--help-manual)
+COMPREPLY=( $( compgen -W '$( ctest --help-manual-list 2>/dev/null|
+grep -v "^ctest version " | sed -e "s/([0-9])$//" )' -- "$cur" 
) )
+return
+;;
+--help-module)
+COMPREPLY=( $( compgen -W '$( ctest --help-module-list 2>/dev/null|
+grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-policy)
+COMPREPLY=( $( compgen -W '$( ctest --help-policies 2>/dev/null |
+grep "^  CMP" 2>/dev/null )' -- "$cur" ) )
+return
+;;
+--help-property)
+COMPREPLY=( $( compgen -W '$( ctest --help-property-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
+--help-variable)
+COMPREPLY=( $( compgen -W '$( ctest --help-variable-list \
+2>/dev/null | grep -v "^ctest version " )' -- "$cur" ) )
+return
+;;
 esac
 
 if [[ "$cur" == -* ]]; then

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=846d2

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-205-gceb8b83

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  ceb8b8371ad2426dec35210e0de96fda69bc6c9a (commit)
   via  63c0e92c9395083a61fe31cd89bee7e3814f10e8 (commit)
   via  6eee24634bc1791a64f8146c0f79c769eb9dfb83 (commit)
   via  120899c6980fcd81aa2a0d7b733ae15332a7a133 (commit)
   via  7066218e792927cb6494ce73e834b8ddb3d275e6 (commit)
  from  88ae1dea8b44cbd456e07ad372d8f0ee14b5d8a3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ceb8b8371ad2426dec35210e0de96fda69bc6c9a
commit ceb8b8371ad2426dec35210e0de96fda69bc6c9a
Merge: 88ae1de 63c0e92
Author: Brad King 
AuthorDate: Fri Jun 10 09:34:54 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:34:54 2016 -0400

Merge topic 'expose-cache-properties' into next

63c0e92c cmState: Expose list of properties of values in the cache
6eee2463 cmCacheEntry: Retrieve all properties of cache entries
120899c6 cmPropertyList: Add a way to retrieve all properties
7066218e cmake: Kill cmake::CacheManager and its getter


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=63c0e92c9395083a61fe31cd89bee7e3814f10e8
commit 63c0e92c9395083a61fe31cd89bee7e3814f10e8
Author: Tobias Hunger 
AuthorDate: Fri Jun 10 10:10:07 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:33:41 2016 -0400

cmState: Expose list of properties of values in the cache

diff --git a/Source/cmState.cxx b/Source/cmState.cxx
index 04f07ce..d2cfaba 100644
--- a/Source/cmState.cxx
+++ b/Source/cmState.cxx
@@ -246,6 +246,14 @@ void cmState::SetCacheEntryBoolProperty(std::string const& 
key,
   it.SetProperty(propertyName, value);
 }
 
+std::vector cmState::GetCacheEntryPropertyList(
+  const std::string& key)
+{
+  cmCacheManager::CacheIterator it =
+this->CacheManager->GetCacheIterator(key.c_str());
+  return it.GetPropertyList();
+}
+
 const char* cmState::GetCacheEntryProperty(std::string const& key,
std::string const& propertyName)
 {
diff --git a/Source/cmState.h b/Source/cmState.h
index 18c45b8..935faec 100644
--- a/Source/cmState.h
+++ b/Source/cmState.h
@@ -247,6 +247,7 @@ public:
  std::string const& value);
   void SetCacheEntryBoolProperty(std::string const& key,
  std::string const& propertyName, bool value);
+  std::vector GetCacheEntryPropertyList(std::string const& key);
   const char* GetCacheEntryProperty(std::string const& key,
 std::string const& propertyName);
   bool GetCacheEntryPropertyAsBool(std::string const& key,

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6eee24634bc1791a64f8146c0f79c769eb9dfb83
commit 6eee24634bc1791a64f8146c0f79c769eb9dfb83
Author: Tobias Hunger 
AuthorDate: Fri Jun 10 09:34:49 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:33:41 2016 -0400

cmCacheEntry: Retrieve all properties of cache entries

diff --git a/Source/cmCacheManager.cxx b/Source/cmCacheManager.cxx
index 676e84a..233d9ca 100644
--- a/Source/cmCacheManager.cxx
+++ b/Source/cmCacheManager.cxx
@@ -539,6 +539,11 @@ void cmCacheManager::CacheIterator::Next()
   }
 }
 
+std::vector cmCacheManager::CacheIterator::GetPropertyList() const
+{
+  return this->GetEntry().GetPropertyList();
+}
+
 void cmCacheManager::CacheIterator::SetValue(const char* value)
 {
   if (this->IsAtEnd()) {
@@ -558,6 +563,11 @@ bool cmCacheManager::CacheIterator::GetValueAsBool() const
   return cmSystemTools::IsOn(this->GetEntry().Value.c_str());
 }
 
+std::vector cmCacheManager::CacheEntry::GetPropertyList() const
+{
+  return this->Properties.GetPropertyList();
+}
+
 const char* cmCacheManager::CacheEntry::GetProperty(
   const std::string& prop) const
 {
diff --git a/Source/cmCacheManager.h b/Source/cmCacheManager.h
index e9b80cb..153e957 100644
--- a/Source/cmCacheManager.h
+++ b/Source/cmCacheManager.h
@@ -38,6 +38,7 @@ private:
 std::string Value;
 cmState::CacheEntryType Type;
 cmPropertyMap Properties;
+std::vector GetPropertyList() const;
 const char* GetProperty(const std::string&) const;
 void SetProperty(const std::string& property, const char* value);
 void AppendProperty(const std::string& property, const char* value,
@@ -60,6 +61,7 @@ public:
 bool IsAtEnd() const;
 void Next();
 std::string GetName() const { return this->Position->first; }
+std::vector GetPropertyList() const;
 const char* GetProperty(const std::string&) const;
 bool GetPropertyAsBool(const std::string&) const;
 bool PropertyExists(const std::string&) con

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-200-g88ae1de

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  88ae1dea8b44cbd456e07ad372d8f0ee14b5d8a3 (commit)
   via  f62ed322dc0d859f595be5ddeff40904ee478f50 (commit)
   via  853b1bb4ba176e886e3682a2475f1de1932ee890 (commit)
  from  efe13e2f0b16754a1a87b04e75421d29bd223573 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=88ae1dea8b44cbd456e07ad372d8f0ee14b5d8a3
commit 88ae1dea8b44cbd456e07ad372d8f0ee14b5d8a3
Merge: efe13e2 f62ed32
Author: Brad King 
AuthorDate: Fri Jun 10 09:26:52 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:26:52 2016 -0400

Merge topic 'refactor-cmLocalGenerator-flags' into next

f62ed322 cmLocalGenerator: Add GetTargetDefines to get all defines for a 
target
853b1bb4 cmLocalGenerator: Constify AppendDefines and AddCompileDefinitions


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f62ed322dc0d859f595be5ddeff40904ee478f50
commit f62ed322dc0d859f595be5ddeff40904ee478f50
Author: Tobias Hunger 
AuthorDate: Wed Jun 8 13:23:25 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 09:24:49 2016 -0400

cmLocalGenerator: Add GetTargetDefines to get all defines for a target

diff --git a/Source/cmCommonTargetGenerator.cxx 
b/Source/cmCommonTargetGenerator.cxx
index 131b490..b893dd3 100644
--- a/Source/cmCommonTargetGenerator.cxx
+++ b/Source/cmCommonTargetGenerator.cxx
@@ -246,19 +246,11 @@ std::string cmCommonTargetGenerator::GetDefines(const 
std::string& l)
   ByLanguageMap::iterator i = this->DefinesByLanguage.find(l);
   if (i == this->DefinesByLanguage.end()) {
 std::set defines;
-const char* lang = l.c_str();
-// Add the export symbol definition for shared library objects.
-if (const char* exportMacro = this->GeneratorTarget->GetExportMacro()) {
-  this->LocalGenerator->AppendDefines(defines, exportMacro);
-}
-
-// Add preprocessor definitions for this target and configuration.
-this->LocalGenerator->AddCompileDefinitions(
-  defines, this->GeneratorTarget, this->LocalGenerator->GetConfigName(),
-  l);
+this->LocalGenerator->GetTargetDefines(this->GeneratorTarget,
+   this->ConfigName, l, defines);
 
 std::string definesString;
-this->LocalGenerator->JoinDefines(defines, definesString, lang);
+this->LocalGenerator->JoinDefines(defines, definesString, l);
 
 ByLanguageMap::value_type entry(l, definesString);
 i = this->DefinesByLanguage.insert(entry).first;
diff --git a/Source/cmLocalGenerator.cxx b/Source/cmLocalGenerator.cxx
index 3f957f0..2ccaa82 100644
--- a/Source/cmLocalGenerator.cxx
+++ b/Source/cmLocalGenerator.cxx
@@ -1329,6 +1329,20 @@ std::string 
cmLocalGenerator::GetFrameworkFlags(std::string const& l,
   return ::GetFrameworkFlags(l, config, target);
 }
 
+void cmLocalGenerator::GetTargetDefines(cmGeneratorTarget const* target,
+std::string const& config,
+std::string const& lang,
+std::set& defines) const
+{
+  // Add the export symbol definition for shared library objects.
+  if (const char* exportMacro = target->GetExportMacro()) {
+this->AppendDefines(defines, exportMacro);
+  }
+
+  // Add preprocessor definitions for this target and configuration.
+  this->AddCompileDefinitions(defines, target, config, lang.c_str());
+}
+
 std::string cmLocalGenerator::ConvertToLinkReference(std::string const& lib,
  OutputFormat format)
 {
diff --git a/Source/cmLocalGenerator.h b/Source/cmLocalGenerator.h
index ad77c1f..55b8794 100644
--- a/Source/cmLocalGenerator.h
+++ b/Source/cmLocalGenerator.h
@@ -314,6 +314,9 @@ public:
   std::string& flags, std::string& linkFlags,
   std::string& frameworkPath, std::string& linkPath,
   cmGeneratorTarget* target, bool useWatcomQuote);
+  void GetTargetDefines(cmGeneratorTarget const* target,
+std::string const& config, std::string const& lang,
+std::set& defines) const;
 
   std::string GetFrameworkFlags(std::string const& l,
 std::string const& config,

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=853b1bb4ba176e886e3682a2475f1de1932ee890
commit 853b1bb4ba176e886e3682a2475f1de1932ee890
Author: Brad King 
AuthorDate: Fri Jun 10 09:23:14 2016 -0400
Commit: Brad King 
CommitDate: Fri Jun 10 09:24:11 2016 -0400

cmLocalGenerator: Constify AppendDefines and AddCom

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-197-gefe13e2

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  efe13e2f0b16754a1a87b04e75421d29bd223573 (commit)
   via  98aafb2ad64daa0617b3a71ec61f692d5aa205ce (commit)
   via  ff4697fc94d74e8c08d165837add668ccb5a5fad (commit)
   via  fbf461dde26aca7bb4b44d0f25e459ea30e3aa87 (commit)
   via  09e6c9eba7905b4af19dcdc18d8fe5c8d337218c (commit)
   via  b29f1514d012fb3036fd4579ccfb4004c20d8771 (commit)
   via  5d078868f00ff8dd514c7c35542aaf2eb0b5ef5f (commit)
   via  1bde72a390fd734795a3f5f4d09a3e279b5d61b8 (commit)
   via  1f9b35da101ba12f5c6d8cdbe8e073fa8709709a (commit)
  from  bcd209460fb45bc04ed0e99d23fac5c3c2e2c213 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=efe13e2f0b16754a1a87b04e75421d29bd223573
commit efe13e2f0b16754a1a87b04e75421d29bd223573
Merge: bcd2094 98aafb2
Author: Brad King 
AuthorDate: Fri Jun 10 09:10:43 2016 -0400
Commit: Brad King 
CommitDate: Fri Jun 10 09:10:43 2016 -0400

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
diff --git a/Modules/FindPkgConfig.cmake b/Modules/FindPkgConfig.cmake
index 644687c..33290c4 100644
--- a/Modules/FindPkgConfig.cmake
+++ b/Modules/FindPkgConfig.cmake
@@ -316,9 +316,13 @@ macro(_pkg_check_modules_internal _is_required _is_silent 
_no_cmake_path _no_cma
 list(APPEND _lib_dirs 
"lib/${CMAKE_LIBRARY_ARCHITECTURE}/pkgconfig")
   endif()
 else()
   # not debian, chech the FIND_LIBRARY_USE_LIB64_PATHS property
FIND_LIBRARY_USE_LIB64_PATHS properties
+  get_property(uselib32 GLOBAL PROPERTY FIND_LIBRARY_USE_LIB32_PATHS)
+  if(uselib32 AND CMAKE_SIZEOF_VOID_P EQUAL 4)
+list(APPEND _lib_dirs "lib

[Cmake-commits] CMake branch, next, updated. v3.6.0-rc1-228-g6fc549f

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  6fc549fd0f5c1ad49aab7beb0c9a8ea90d7f1aed (commit)
   via  797c3c54e835e5c5131f38036aca61b0dae02260 (commit)
   via  b08cae9b0e9bad96e4615c1bbf9bbd00802e6985 (commit)
   via  48cb388ead09794aae01328d83620e10a8f7636b (commit)
  from  78dddcaf7e33e7d70516901699c7315ed53e7eca (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6fc549fd0f5c1ad49aab7beb0c9a8ea90d7f1aed
commit 6fc549fd0f5c1ad49aab7beb0c9a8ea90d7f1aed
Merge: 78dddca 797c3c5
Author: Brad King 
AuthorDate: Fri Jun 10 10:47:28 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 10:47:28 2016 -0400

Merge topic 'bash-completion' into next

797c3c54 bash-completion: Add cpack --help-{manual,module,policy,property}
b08cae9b bash-completion: Add ctest 
--help-{manual,module,policy,property,variable}
@@ -316,9 +316,13 @@ macro(_pkg_check_modules_internal _is_required _is_silent 
   endif()
 else()
-  # not debian, chech the FIND_LIBRARY_USE_LIB64_PATHS property
+  # not debian, check the FIND_LIBRARY_USE_LIB32_PATHS and 
FIND_LIBRARY_USE_LIB64_PATHS properties
48cb388e bash-completion: Fix cmake --help-policy lookup


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=797c3c54e835e5c5131f38036aca61b0dae02260
commit 797c3c54e835e5c5131f38036aca61b0dae02260
Author: Eric NOULARD 
AuthorDate: Fri Jun 10 15:28:05 2016 +0200
Commit: Brad King 
CommitDate: Fri Jun 10 10:46:33 2016 -0400

bash-completion: Add cpack --help-{manual,module,policy,property}

-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-104-g98aafb2

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  98aafb2ad64daa0617b3a71ec61f692d5aa205ce (commit)
   via  d9613b962e2ed5c908850c8a083630f753dac113 (commit)
   via  70d3bf85808d17dba8ec90e2975f2741383ef260 (commit)
   via  de4ee088e7ab60213b551ecf98bc9e1b512ee393 (commit)
  from  ff4697fc94d74e8c08d165837add668ccb5a5fad (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=98aafb2ad64daa0617b3a71ec61f692d5aa205ce
commit 98aafb2ad64daa0617b3a71ec61f692d5aa205ce
Merge: ff4697f d9613b9
Author: Brad King 
AuthorDate: Fri Jun 10 09:10:04 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:10:04 2016 -0400

Merge topic 'refactor-cmLocalGenerator-flags'

d9613b96 cmLocalGenerator: Move GetFrameworkFlags implementation to private 
helper
70d3bf85 cmLocalGenerator: Adopt GetFrameworkFlags method
de4ee088 cmCommonTargetGenerator: De-duplicate CMAKE_BUILD_TYPE lookup


---

Summary of changes:
 Source/cmCommonTargetGenerator.cxx |   59 +++-
 Source/cmCommonTargetGenerator.h   |3 --
 Source/cmLocalGenerator.cxx|   58 +++
 Source/cmLocalGenerator.h  |4 +++
 4 files changed, 66 insertions(+), 58 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-100-gff4697f

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  ff4697fc94d74e8c08d165837add668ccb5a5fad (commit)
   via  d4b8e8135358024b6982100654a430358574efb2 (commit)
  from  fbf461dde26aca7bb4b44d0f25e459ea30e3aa87 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ff4697fc94d74e8c08d165837add668ccb5a5fad
commit ff4697fc94d74e8c08d165837add668ccb5a5fad
Merge: fbf461d d4b8e81
Author: Brad King 
AuthorDate: Fri Jun 10 09:10:02 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:10:02 2016 -0400

Merge topic 'FindProtobuf-proto-in-subdirs'

d4b8e813 FindProtobuf: fix protobuf_generate_*() to handle proto files in 
subdirs.


---

Summary of changes:
 Modules/FindProtobuf.cmake |8 
 1 file changed, 8 insertions(+)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-98-gfbf461d

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  fbf461dde26aca7bb4b44d0f25e459ea30e3aa87 (commit)
   via  746a4245738c7b3c0b29754cb09b2230697f13fc (commit)
  from  09e6c9eba7905b4af19dcdc18d8fe5c8d337218c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fbf461dde26aca7bb4b44d0f25e459ea30e3aa87
commit fbf461dde26aca7bb4b44d0f25e459ea30e3aa87
Merge: 09e6c9e 746a424
Author: Brad King 
AuthorDate: Fri Jun 10 09:09:59 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:09:59 2016 -0400

Merge topic 'FindFreetype-dedup-arguments'

746a4245 FindFreetype: Factor out common find command arguments


---

Summary of changes:
 Modules/FindFreetype.cmake |   35 ---
 1 file changed, 12 insertions(+), 23 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-91-g5d07886

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  5d078868f00ff8dd514c7c35542aaf2eb0b5ef5f (commit)
   via  ceebac93f66c3927997b708caf6f2eb2d1827593 (commit)
  from  1bde72a390fd734795a3f5f4d09a3e279b5d61b8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5d078868f00ff8dd514c7c35542aaf2eb0b5ef5f
commit 5d078868f00ff8dd514c7c35542aaf2eb0b5ef5f
Merge: 1bde72a ceebac9
Author: Brad King 
AuthorDate: Fri Jun 10 09:09:50 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:09:50 2016 -0400

Merge topic 'watcom-workaround'

ceebac93 Tests: Restore fix to Plugin test on Watcom compiler


---

Summary of changes:
 Tests/Plugin/src/example_exe.cxx |4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-93-gb29f151

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  b29f1514d012fb3036fd4579ccfb4004c20d8771 (commit)
   via  e937b4c3879e1ee0770b465c0cdcbb6a960ba892 (commit)
  from  5d078868f00ff8dd514c7c35542aaf2eb0b5ef5f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b29f1514d012fb3036fd4579ccfb4004c20d8771
commit b29f1514d012fb3036fd4579ccfb4004c20d8771
Merge: 5d07886 e937b4c
Author: Brad King 
AuthorDate: Fri Jun 10 09:09:54 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:09:54 2016 -0400

Merge topic 'FindOpenSSL-BoringSSL'

e937b4c3 FindOpenSSL: Do not assume that the version regex finds something


---

Summary of changes:
 Modules/FindOpenSSL.cmake |8 
 1 file changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-96-g09e6c9e

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  09e6c9eba7905b4af19dcdc18d8fe5c8d337218c (commit)
   via  7229ae728fa703390b70a9ded5606b01214c14de (commit)
   via  e9bfe8da04c5486335d15c68b544f25f940c9c92 (commit)
  from  b29f1514d012fb3036fd4579ccfb4004c20d8771 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=09e6c9eba7905b4af19dcdc18d8fe5c8d337218c
commit 09e6c9eba7905b4af19dcdc18d8fe5c8d337218c
Merge: b29f151 7229ae7
Author: Brad King 
AuthorDate: Fri Jun 10 09:09:57 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:09:57 2016 -0400

Merge topic 'FindCUDA-android'

7229ae72 FindCUDA: Refactor Android(Tegra) support
e9bfe8da FindCUDA: Adjust vertical whitespace


---

Summary of changes:
 Modules/FindCUDA.cmake |  140 +---
 Modules/FindCUDA/select_compute_arch.cmake |  195 
 2 files changed, 287 insertions(+), 48 deletions(-)
 create mode 100644 Modules/FindCUDA/select_compute_arch.cmake


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.6.0-rc1-89-g1bde72a

2016-06-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  1bde72a390fd734795a3f5f4d09a3e279b5d61b8 (commit)
   via  f28401554af8fe48994b0c08668f0c1408708fe1 (commit)
  from  1f9b35da101ba12f5c6d8cdbe8e073fa8709709a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1bde72a390fd734795a3f5f4d09a3e279b5d61b8
commit 1bde72a390fd734795a3f5f4d09a3e279b5d61b8
Merge: 1f9b35d f284015
Author: Brad King 
AuthorDate: Fri Jun 10 09:09:47 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Fri Jun 10 09:09:47 2016 -0400

Merge topic 'cmake-gui-osx-symlink-qt5-plugin'

f2840155 cmake-gui: Teach Qt5 where plugins are when launched through a 
symlink


---

Summary of changes:
 Source/QtDialog/CMakeSetup.cxx |   34 ++
 1 file changed, 34 insertions(+)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits